@@ -11,15 +11,15 @@
 #define VERSION_EXTRA ""
 
 /* Version number of Wireshark and associated utilities */
-#define VERSION "4.4.9"
+#define VERSION "4.6.0"
 #define VERSION_MAJOR 4
-#define VERSION_MINOR 4
-#define VERSION_MICRO 9
+#define VERSION_MINOR 6
+#define VERSION_MICRO 0
 
-/* Version number of Logray and associated utilities */
-#define LOG_VERSION "0.9.0"
+/* Version number of Stratoshark and associated utilities */
+#define STRATOSHARK_VERSION "0.9.3rc0-972-gcdfb6721e77c"
 
-#define PLUGIN_PATH_ID "4.4"
+#define PLUGIN_PATH_ID "4.6"
 #define VERSION_FLAVOR ""
 
 /* Build wsutil with SIMD optimization */
@@ -31,14 +31,14 @@
 /*  Define to 1 if we check hf conflict */
 /* #undef ENABLE_CHECK_FILTER */
 
-/* Link Wireshark libraries statically */
-/* #undef ENABLE_STATIC */
-
 /* Enable AddressSanitizer (and LeakSanitizer on clang/gcc) */
 /* #undef ENABLE_ASAN */
 
-/* Enable AirPcap */
-/* #undef HAVE_AIRPCAP */
+/* Enable LeakSanitizer standalone */
+/* #undef ENABLE_LSAN */
+
+/* Adapt build products for fuzzing (e.g. accepting incorrect checksums or prioritizing determinism). */
+/* #undef FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION */
 
 /* Define to 1 if you have the <arpa/inet.h> header file. */
 #define HAVE_ARPA_INET_H 1
@@ -63,6 +63,9 @@
 
 /* Define to use the MaxMind DB library */
 /* #undef HAVE_MAXMINDDB */
+/* MaxmindDB version */
+#define MAXMINDDB_VERSION ""
+
 
 /* Define to 1 if you have the <ifaddrs.h> header file. */
 #define HAVE_IFADDRS_H 1
@@ -125,17 +128,11 @@
 #define HAVE_LIBGNUTLS 1
 
 /* Define to 1 if GnuTLS was built with pkcs11 support. */
-#define HAVE_GNUTLS_PKCS11 1
+/* #undef HAVE_GNUTLS_PKCS11 */
 
 /* Enable libnl support */
 #define HAVE_LIBNL 1
 
-/* libnl version 1 */
-/* #undef HAVE_LIBNL1 */
-
-/* libnl version 2 */
-/* #undef HAVE_LIBNL2 */
-
 /* libnl version 3 */
 #define HAVE_LIBNL3 1
 
@@ -148,6 +145,10 @@
 /* Define to 1 if libsmi exports a version string (and that symbol is visible). */
 /* #undef HAVE_SMI_VERSION_STRING */
 
+/* Define to use xxhash library */
+/* #undef HAVE_XXHASH */
+#define XXHASH_VERSION_STRING ""
+
 /* Define to use zlib library */
 #define HAVE_ZLIB 1
 
@@ -170,13 +171,14 @@
 /* #undef HAVE_BROTLI */
 
 /* Define to use lz4 library */
-/* #undef HAVE_LZ4 */
+#define HAVE_LZ4 1
 
 /* Check for lz4frame */
-/* #undef HAVE_LZ4FRAME_H */
+#define HAVE_LZ4FRAME_H 1
 
 /* Define to use snappy library */
 /* #undef HAVE_SNAPPY */
+#define SNAPPY_VERSION ""
 
 /* Define to use zstd library */
 #define HAVE_ZSTD 1
@@ -217,45 +219,27 @@
 /* VHT_CAPABILITY is supported */
 #define HAVE_NL80211_VHT_CAPABILITY 1
 
+/* HE_CAPABILITY is supported */
+#define HAVE_NL80211_HE_CAPABILITY 1
+
+/* EHT_CAPABILITY is supported */
+#define HAVE_NL80211_EHT_CAPABILITY 1
+
 /* Define to 1 if you have macOS frameworks */
 /* #undef HAVE_MACOS_FRAMEWORKS */
 
 /* Define to 1 if you have the macOS CFPropertyListCreateWithStream function */
 /* #undef HAVE_CFPROPERTYLISTCREATEWITHSTREAM */
 
-/* Define to 1 if you have the `pcap_create' function. */
-#define HAVE_PCAP_CREATE 1
-
-/* Define to 1 if the capture buffer size can be set. */
-#define CAN_SET_CAPTURE_BUFFER_SIZE 1
-
-/* Define to 1 if you have the `pcap_freecode' function. */
-#define HAVE_PCAP_FREECODE 1
-
-/* Define to 1 if you have the `pcap_free_datalinks' function. */
-#define HAVE_PCAP_FREE_DATALINKS 1
-
 /* Define to 1 if you have the `pcap_open' function. */
 /* #undef HAVE_PCAP_OPEN */
 
-/* Define to 1 if you have libpcap/WinPcap/Npcap remote capturing support. */
+/* Define to 1 if you have libpcap/Npcap remote capturing support. */
 /* #undef HAVE_PCAP_REMOTE */
 
 /* Define to 1 if you have the `pcap_setsampling' function. */
 /* #undef HAVE_PCAP_SETSAMPLING */
 
-/* Define to 1 if you have the `pcap_set_tstamp_precision' function. */
-#define HAVE_PCAP_SET_TSTAMP_PRECISION 1
-
-/* Define to 1 if you have the `pcap_set_tstamp_type' function. */
-#define HAVE_PCAP_SET_TSTAMP_TYPE 1
-
-/* Define to 1 if you have the `PCAP_ERROR_PROMISC_PERM_DENIED' symbol. */
-#define HAVE_PCAP_ERROR_PROMISC_PERM_DENIED 1
-
-/* Define to 1 if you have the `PCAP_WARNING_TSTAMP_TYPE_NOTSUP' symbol. */
-#define HAVE_PCAP_WARNING_TSTAMP_TYPE_NOTSUP 1
-
 /* Define to 1 if you have the <pwd.h> header file. */
 #define HAVE_PWD_H 1
 
@@ -275,10 +259,7 @@
 /* #undef HAVE_ILBC */
 
 /* Define to 1 if you have the opus library. */
-/* #undef HAVE_OPUS */
-
-/* Define to 1 if you have the lixbml2 library. */
-/* #undef HAVE_LIBXML2 */
+#define HAVE_OPUS 1
 
 /* Define to 1 if you have the `setresgid' function. */
 #define HAVE_SETRESGID 1
@@ -421,7 +402,7 @@
  * are added if and only if HAVE_REMOTE is defined, and will fill them in,
  * even if they're not there.
  *
- * Yes, this is q WinPcap bug; if your project has a public header file
+ * Yes, this is a WinPcap bug; if your project has a public header file
  * that checks or otherwise uses a #define that's defined by your project's
  * configuration process, and don't ensure that it's always defined
  * appropriately when that header file is included, before its first use,
@@ -445,6 +426,10 @@
  * No version of the WinPcap SDK provided libpcap 1.9.0-or-later headers.
  * The Npcap SDK, as of SDK version 1.04, provides them, so this is
  * only necessary for building with the WinPcap SDK.
+ *
+ * Building against the WinPcap SDK isn't supported anymore, nor is running
+ * with the WinPcap DLL installed, so needing this is very unlikely, though
+ * libpcap 1.9.0 or later is not yet required.
  */
 #ifdef HAVE_PCAP_REMOTE
 #define HAVE_REMOTE
